summaryrefslogtreecommitdiff
path: root/build.c
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2001-10-28 22:17:47 +0000
committerjbj <devnull@localhost>2001-10-28 22:17:47 +0000
commit966fabbc441b5d859ecda64fe926be3912603fe5 (patch)
treea8cc37298737e3d0af890e13d3e0a33e2f4014f3 /build.c
parentc1d367a0941b3778a84252691bbd294a0a8be4b7 (diff)
downloadrpm-966fabbc441b5d859ecda64fe926be3912603fe5.tar.gz
rpm-966fabbc441b5d859ecda64fe926be3912603fe5.tar.bz2
rpm-966fabbc441b5d859ecda64fe926be3912603fe5.zip
- memory indices for dependency check are typedef'd and abstract'd.
- no-brainer refcounts for fi object, debug the mess. - dump the header early in transaction, recreate fi before installing. CVS patchset: 5137 CVS date: 2001/10/28 22:17:47
Diffstat (limited to 'build.c')
-rw-r--r--build.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/build.c b/build.c
index bd281269e..792fdc7bc 100644
--- a/build.c
+++ b/build.c
@@ -17,8 +17,8 @@
/**
*/
static int checkSpec(rpmTransactionSet ts, Header h)
/*@globals fileSystem @*/
/*@modifies ts, h, fileSystem @*/
{
rpmDependencyConflict conflicts;
int numConflicts;
@@ -92,7 +92,8 @@ static int isSpecFile(const char * specfile)
static int buildForTarget(rpmTransactionSet ts, const char * arg, BTA_t ba)
/*@globals rpmGlobalMacroContext,
fileSystem, internalState @*/
- /*@modifies ts, rpmGlobalMacroContext, fileSystem, internalState @*/
+ /*@modifies ts, rpmGlobalMacroContext,
+ fileSystem, internalState @*/
{
const char * passPhrase = ba->passPhrase;
const char * cookie = ba->cookie;
@@ -17,8 +17,8 @@
*/
static int checkSpec(rpmTransactionSet ts, Header h)
- /*@globals fileSystem @*/
- /*@modifies ts, h, fileSystem @*/
+ /*@globals fileSystem, internalState @*/
+ /*@modifies ts, h, fileSystem, internalState @*/
{
rpmDependencyConflict conflicts;